# -*- coding: utf-8 -*-
#
# Copyright (C) 2020 CERN.
#
# Invenio-Drafts-Resources is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Version information for Invenio-Drafts-Resources.

This file is imported by ``invenio_drafts_resources.__init__``,
and parsed by ``setup.py``.
"""

__version__ = "0.1.0"
